@@ -32,6 +32,8 @@ Same as L<R::NDArray#data|SPVM::R::NDArray/"data"> method, but the return type i
 
 =head1 Class Methods
 
+=head2 new
+
 C<static method new : L<R::NDArray::Float|SPVM::R::NDArray::Float> ($options : object[] = undef);>
 
 Creates a new L<R::NDArray::Float|SPVM::R::NDArray::Float> and returns it.
@@ -66,9 +68,9 @@ Copies the element $src_data at index $src_data_indext to the element $dist_data
 
 =head2 elem_cmp
 
-C<method elem_cmp : int ($data : float[], $a_data_index : int, $b_data_index : int);>
+C<method elem_cmp : int ($a_data : float[], $a_data_index : int, $b_data : float[], $b_data_index : int);>
 
-Compares the element $data at index $a_data_index and the element $data at index $b_data_index and returns the result.
+Compares the element $a_data at index $a_data_index and the element $b_data at index $b_data_index and returns the result.
 
 =head2 elem_is_na
 
